@@ -14,7 +14,8 @@
 #include <QDir>
 
 #include <arianna_debug.h>
-#include <qstringliteral.h>
+
+using namespace Qt::StringLiterals;
 
 class BookDatabase::Private
 {
@@ -149,7 +150,6 @@ QList<BookEntry> BookDatabase::loadEntries()
     }
 
     QList<BookEntry> entries;
-    QStringList entryNames = d->fieldNames;
     QSqlQuery allEntries(QStringLiteral("SELECT ") + d->fieldNames.join(QStringLiteral(", ")) + QStringLiteral(" FROM books"));
 
     while (allEntries.next()) {
@@ -167,7 +167,7 @@ std::optional<BookEntry> BookDatabase::loadEntry(const QString &fileName)
     }
     QSqlQuery entry;
     entry.prepare(QStringLiteral("SELECT ") + d->fieldNames.join(QStringLiteral(", ")) + QStringLiteral(" FROM books WHERE fileName = :fileName LIMIT 1"));
-    entry.bindValue(QLatin1String(":fileName"), fileName);
+    entry.bindValue(QStringLiteral(":fileName"), fileName);
     if (entry.exec()) {
         entry.first();
         return d->fromSqlQuery(entry);
@@ -245,15 +245,15 @@ void BookDatabase::updateEntry(const QString &fileName, const QString &property,
         return;
     }
 
-    QStringList stringListValues;
-    // clang-format off
-    stringListValues << QStringLiteral("series")
-                     << QStringLiteral("author")
-                     << QStringLiteral("characters")
-                     << QStringLiteral("genres")
-                     << QStringLiteral("keywords")
-                     << QStringLiteral("tags");
-    // clang-format on
+    const QStringList stringListValues{
+        u"series"_s,
+        u"author"_s,
+        u"character"_s
+        u"genres"_s,
+        u"keywords"_s,
+        u"tags"_s,
+    };
+
     QString val;
     if (stringListValues.contains(property)) {
         val = value.toStringList().join(QLatin1Char(','));
